@@ -1,8 +1,9 @@
-import typing
 from enum import IntEnum
 
 from qtpy import QtWidgets, QtCore
 
+from .menu import RibbonMenu
+
 
 class RibbonButtonStyle(IntEnum):
     """Button style, Small, Medium, or Large."""
@@ -14,7 +15,6 @@ class RibbonButtonStyle(IntEnum):
 class RibbonToolButton(QtWidgets.QToolButton):
     """Tool button that is showed in the ribbon."""
     _buttonStyle: RibbonButtonStyle
-    _actions: typing.List[QtWidgets.QAction]
 
     _largeButtonIconSize = 64
     _mediumButtonIconSize = 48
@@ -26,16 +26,12 @@ class RibbonToolButton(QtWidgets.QToolButton):
         :param parent: The parent widget.
         """
         super().__init__(parent)
-        self._actions = []
 
         # Styles
         self.setButtonStyle(RibbonButtonStyle.Large)
         self.setAutoRaise(True)
         self.setFocusPolicy(QtCore.Qt.NoFocus)
 
-        # Connect signals
-        self.triggered.connect(self.setDefaultAction)
-
     def setButtonStyle(self, style: RibbonButtonStyle):
         """Set the button style of the button.
 
@@ -46,40 +42,59 @@ class RibbonToolButton(QtWidgets.QToolButton):
             height = self._smallButtonIconSize
             self.setIconSize(QtCore.QSize(height, height))
             self.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
+            self.setStyleSheet(
+                """
+                RibbonToolButton::menu-indicator {
+                    subcontrol-origin: padding;
+                    subcontrol-position: right;
+                    right: -5px;
+                }
+                """
+            )
         elif style == RibbonButtonStyle.Medium:
             height = self._mediumButtonIconSize
             self.setIconSize(QtCore.QSize(height, height))
             self.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
+            self.setStyleSheet(
+                """
+                RibbonToolButton::menu-indicator {
+                    subcontrol-origin: padding;
+                    subcontrol-position: right;
+                    right: -5px;
+                }
+                """
+            )
         elif style == RibbonButtonStyle.Large:
             height = self._largeButtonIconSize
             self.setIconSize(QtCore.QSize(height, height))
             self.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+            self.setStyleSheet(
+                """
+                RibbonToolButton[popupMode="0"]::menu-indicator {
+                    subcontrol-origin: padding;
+                    subcontrol-position: bottom;
+                    bottom: -5px;
+                }
+                RibbonToolButton[popupMode="2"]::menu-indicator {
+                    subcontrol-origin: padding;
+                    subcontrol-position: bottom;
+                    bottom: -5px;
+                }
+                """
+            )
 
-    def setMenu(self, menu: QtWidgets.QMenu):
-        """Set the menu of the button.
+    def buttonStyle(self) -> RibbonButtonStyle:
+        """Get the button style of the button.
 
-        :param menu: The menu of the button.
+        :return: The button style of the button.
         """
-        super().setMenu(menu)
-        self.setPopupMode(QtWidgets.QToolButton.InstantPopup)
-        if self.menu().actions():
-            self.setDefaultAction(self.menu().actions()[0])
+        return self._buttonStyle
 
-    def addAction(self, action: QtWidgets.QAction) -> None:
-        """Add an action to the button.
+    def addRibbonMenu(self) -> RibbonMenu:
+        """Add a ribbon menu for the button.
 
-        :param action: The action to add.
+        :return: The added ribbon menu.
         """
-        if len(self._actions) == 0:
-            self.setDefaultAction(action)
-            self.setMenu(QtWidgets.QMenu())
-        self._actions.append(action)
-        self.menu().addAction(action)
-
-    def addActions(self, actions: typing.Iterable[QtWidgets.QAction]) -> None:
-        """Add actions to the button.
-
-        :param actions: The actions to add.
-        """
-        for action in actions:
-            self.addAction(action)
+        menu = RibbonMenu()
+        self.setMenu(menu)
+        return menu
